.. include:: ../BADGES.rst

.. _astronomia_documentation:

astronomia
==========
This is the home page for astronomia.  astronomia is a small Python library for
calculating the ephemeris of the Sun, Moon, and planets.  It also has some
utilities for working with time and angles.

astronomia will work with Python 3.6+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   models
   applications
   contributing
   authors
   todo
   license

Python API Documentation
------------------------

.. toctree::
   :maxdepth: 2

   astronomia
   function_summary

Other Projects
--------------
http://timcera.bitbucket.io
